==> moobius-1.2.3-py3-none-any.whl: moobius/database/redis_database.py <==
import json, redis
from .database_interface import DatabaseInterface

from moobius.utils import EnhancedJSONEncoder
from loguru import logger

autosave = False # Only set True for debugging, saving is O(N)!


class RedisDatabase(DatabaseInterface):
    """The redis database make use of a redis.Redis(...) server (Redis servers are set to localhost:6379 by default)."""
    def __init__(self, domain='', host="localhost", port=6379, db=0, password="", **kwargs):
        super().__init__(domain, **kwargs)
        logger.info(f'Redis initialized on {host} port {port}')
        self.redis = redis.Redis(host=host, port=port, db=db, password=password)

    def get_value(self, key) -> (bool, any):
        if self.redis.exists(key):
            balue = self.redis.get(key)
            return True, json.loads(balue.decode())
        return False, f'Key {key} does not exist'

    def set_value(self, key, value) -> (bool, any):
        balue = json.dumps(value, cls=EnhancedJSONEncoder, ensure_ascii=False).encode()
        self.redis.set(key, balue)
        if autosave:
            self.redis.save()
        return True, key

    def delete_key(self, key) -> (bool, any):
        self.redis.delete(key)
        if autosave:
            self.redis.save()
        return True, key

    def all_keys(self) -> any:
        out = self.redis.keys()
        return [k.decode() for k in out]

    def __str__(self):
        return f'moobius.RedisDatabase({self.redis})'
    def __repr__(self):
        return self.__str__()

==> moobius-1.3.7-py3-none-any.whl: moobius/database/redis_database.py <==
# Uses Redis, an in-memory database, to improve performance. Requires a running Redis server.
import json, redis
from .database_interface import DatabaseInterface

from moobius.utils import EnhancedJSONEncoder
from loguru import logger

autosave = False # Only set True for debugging, saving is O(N)!


class RedisDatabase(DatabaseInterface):
    """The redis database make use of a redis.Redis(...) server (Redis servers are set to localhost:6379 by default).
    By default uses the domains's hash code to differentiate different domains, unless a user-supplied "db" value is given."""
    def __init__(self, domain='', host="localhost", port=6379, db=None, password="", **kwargs):
        super().__init__(domain, **kwargs)
        logger.info(f'Redis initialized on {host} port {port}')
        if db is None:
            db = abs(hash(domain))
        self.redis = redis.Redis(host=host, port=port, db=db, password=password)

    def get_value(self, key) -> (bool, any):
        if self.redis.exists(key):
            balue = self.redis.get(key)
            return True, json.loads(balue.decode())
        return False, f'Key {key} does not exist'

    def set_value(self, key, value) -> (bool, any):
        balue = json.dumps(value, cls=EnhancedJSONEncoder, ensure_ascii=False).encode()
        self.redis.set(key, balue)
        if autosave:
            self.redis.save()
        return True, key

    def delete_key(self, key) -> (bool, any):
        self.redis.delete(key)
        if autosave:
            self.redis.save()
        return True, key

    def all_keys(self) -> any:
        out = self.redis.keys()
        return [k.decode() for k in out]

    def __str__(self):
        return f'moobius.RedisDatabase({self.redis})'
    def __repr__(self):
        return self.__str__()
